@@ -5,7 +5,7 @@ use Moo 1.003;
 use Elasticsearch::Util qw(parse_params load_plugin);
 use namespace::clean;
 
-our $VERSION = '0.72';
+our $VERSION = '0.73';
 
 my %Default_Plugins = (
     client      => [ 'Client',       'Direct' ],
@@ -30,7 +30,7 @@ sub new {
 #===================================
     my ( $class, $params ) = parse_params(@_);
 
-    $params->{cxn} ||= 'HTTPTiny';
+    $params->{cxn} ||= 'LWP';
 
     for my $name (@Load_Order) {
         my ( $base, $default ) = @{ $Default_Plugins{$name} };
@@ -41,6 +41,28 @@ sub new {
     return $params->{client};
 }
 
+package    # hide from pause
+    ElasticSearch::Deprecation;
+
+sub new {
+    my $class = shift;
+    die <<DEPRECATION;
+
+It appears that you are using a case-insensitive filesystem. You tried
+to load "ElasticSearch", but you have loaded "Elasticsearch" instead. See:
+
+    https://metacpan.org/release/Elasticsearch
+
+ElasticSearch has been replaced by the official client: Elasticsearch.
+To ease your transition from old to new, please install Elasticsearch::Compat:
+
+    https://metacpan.org/module/Elasticsearch::Compat
+
+DEPRECATION
+}
+
+@ElasticSearch::ISA = 'ElasticSearch::Deprecation';
+
 1;
 
 =pod
@@ -51,7 +73,7 @@ Elasticsearch - The official client for Elasticsearch
 
 =head1 VERSION
 
-version 0.72
+version 0.73
 
 =head1 SYNOPSIS
 
@@ -371,9 +393,10 @@ See :
 
 =over
 
-=item *
+=item * L<Elasticsearch::Client::Direct> (default)
 
-L<Elasticsearch::Client::Direct>.
+=item * L<Elasticsearch::Client::Compat> (for migration from the old
+L<ElasticSearch> module)
 
 =back
 
@@ -385,9 +408,7 @@ retrying after failure where appropriate. See:
 
 =over
 
-=item *
-
-L<Elasticsearch::Transport>
+=item * L<Elasticsearch::Transport>
 
 =back
 
@@ -398,9 +419,11 @@ See:
 
 =over
 
-=item *
+=item * L<Elasticsearch::Cxn::LWP> (default)
 
-L<Elasticsearch::Cxn::HTTPTiny>
+=item * L<Elasticsearch::Cxn::HTTPTiny>
+
+=item * L<Elasticsearch::Cxn::NetCurl>
 
 =back
 
@@ -411,9 +434,7 @@ See:
 
 =over
 
-=item *
-
-L<Elasticsearch::Cxn::Factory>
+=item * L<Elasticsearch::Cxn::Factory>
 
 =back
 
@@ -425,17 +446,11 @@ appropriate. See:
 
 =over
 
-=item *
+=item * L<Elasticsearch::CxnPool::Static> (default)
 
-L<Elasticsearch::CxnPool::Static> (default)
+=item * L<Elasticsearch::CxnPool::Sniff>
 
-=item *
-
-L<Elasticsearch::CxnPool::Sniff>
-
-=item *
-
-L<Elasticsearch::CxnPool::Static::NoPing>
+=item * L<Elasticsearch::CxnPool::Static::NoPing>
 
 =back
 
@@ -446,9 +461,7 @@ requests/responses.  See:
 
 =over
 
-=item *
-
-L<Elasticsearch::Logger::LogAny>
+=item * L<Elasticsearch::Logger::LogAny>
 
 =back
 
@@ -459,14 +472,15 @@ bodies.  See:
 
 =over
 
-=item *
-
-L<Elasticsearch::Serializer::JSON>
+=item * L<Elasticsearch::Serializer::JSON>
 
 =back
 
 =head1 MIGRATING FROM ElasticSearch.pm
 
+See L<Elasticsearch::Compat>, which allows you to run your old
+L<ElasticSearch> code with the new L<Elasticsearch> module.
+
 The L<Elasticseach> API is pretty similar to the old L<ElasticSearch> API,
 but there are a few differences.  The most notable are:
 
@@ -551,15 +565,9 @@ L<Elasticsearch::Scroll>.
 
 =over
 
-=item * L<Elasticsearch::Compat>
+=item * Async support
 
-This module will provide an easy migration path from the old L<ElasticSearch>
-to the new L<Elasticsearch>.
-
-=item * New backends
-
-Release backends for L<LWP>, L<HTTP::Lite>, L<WWW::Curl>, L<Net::Curl>.
-Also add async support via L<AnyEvent> and perhaps L<Mojo>.
+Add async support using L<Promises> for L<AnyEvent> and perhaps L<Mojo>.
 
 =item * New frontend
 
@@ -622,6 +630,11 @@ be run as :
 B<TESTS RUN IN THIS WAY ARE DESTRUCTIVE! DO NOT RUN AGAINST A CLUSTER WITH
 DATA YOU WANT TO KEEP!>
 
+You can change the Cxn class which is used by setting the C<ES_CXN>
+environment variable:
+
+    ES_CXN=HTTPTiny ES=localhost:9200 make test
+
 =head1 AUTHOR
 
 Clinton Gormley <drtech@cpan.org>
